from numpy import log10

def heatTrasferRate(Re, Pr, k, Dh, q):
    """
    Výpočet součinitele přestupu tepla pro jednofázové proudění
    ---
    Re - Reynoldsovo číslo [-]
    Pr - Prandtlovo číslo [-]
    k - tepelná vodivost [W/m/K]
    Dh - hydraulický průměr [m]
    q - tepelný tok [W/m2]
    --->
    h - součinitel přestupu tepla [W/m2/K]
    dT - tepelný spád u stěny [K]
    """
    if Re < 3e3:
        # ~ Nu = 0.332*Class.Re**.5*Class.Pr**0.33
        Nu = 4.36 # uniformní tepelný tok na stěně
    else:
        # Gnielinskiho korelace
        f = fricFactor(Re, Dh)
        Nu = (f/8) * (Re-1e3) * Pr / (1 + 12.7 * (f/8)**.5 * (Pr**0.66 - 1))
    
    h = Nu*k/Dh
    dT = q/h
    return h, dT

def ColebrookWhite(f0, Re, Dh, epsilon):
    """
    Řešič Colebrook-Whiteovy rovnice
    pro určení součinitele třecích ztrát v přechodové oblasti
    ---
    f0 - odhad řešení [-]
    Re - Reynoldsovo číslo [-]
    Dh - hydraulický průměr [m]
    epsilon - absolutní drsnost povrchu [mm]
    -->
    f0 - 
    """
    rel_eps = epsilon/1e3/Dh
    a = rel_eps/3.7
    b = 2.51/Re
    
    # Newtonův řešič Colebrook-Whiteovy rovnice
    df = 1e-5
    err = 1e3
    while abs(err) > 1e-4:
        x = 1/f0**.5
        x_p = 1/(f0+df)**.5
        x_m = 1/(f0-df)**.5
        F_p = -2*log10(a+b*x_p)-x_p
        F_m = -2*log10(a+b*x_m)-x_m
        der = (F_p-F_m)/(2*df)
        f0 = f0 - (-2*log10(a+b*x)-x)/der
        
        x = 1/f0**.5
        err = -2*log10(a+b*x)-x
    return f0

def fricFactor(Re, Dh):
    """
    Darcyho třecí faktor
    Re - Reynoldsovo číslo [-]
    Dh - Hydraulický průměr [m]
    """
    epsilon = 0.15
    if Re <= 2300:
        # Darcy
        # kruhové potrubí
        #K = 64
        # paralelní stěny
        K = 96
        f_lo = K/Re
    elif 1e5 > Re > 2300:
        f_lo0 = 0.3164/Re**.25
        f_lo = ColebrookWhite(f_lo0, Re, Dh, epsilon)
    else:
        # Blasius
        f_lo = 0.3164/Re**.25
    return f_lo

def dp_fric(rho_m, liquid, vapor, Dh, G, x, dz):
    """
    G - hmotnostní tok [kg/m2/s]
    dz - délka úseku [m]
    Dh - hydraulický průměr [m]
    x - suchost [-]
    liquid - třída syté kapaliny
    vapor - třída syté páry
    """
    
    Re = G * Dh / liquid.mu
    f_lo = fricFactor(Re, Dh)
    
    if 0 < x < 1:
        Phi_lo2 = 1+1.2*(liquid.rho/vapor.rho-1)*x+1
        # ~ print(Phi_lo2)
        Phi_lo2 = 1 + x*(liquid.rho/vapor.rho-1)
        # ~ print(Phi_lo2)
    else:
        Phi_lo2 = 1
    
    c = G/rho_m
    
    dp_f = f_lo * Phi_lo2 * c**2/2 * dz/Dh * liquid.rho
    
    return dp_f

def dp_grav(rho,dz):
    """
    rho - hustota [kg/m3]
    dz - délka úseku [m]
    """
    g = 9.81
    return rho*g*dz

def dp_acc(rho_in, rho_out, G):
    """
    rho_in - hustota na vstupu do úseku [kg/m3]
    rho_out - hustota na výstupu z úseku [kg/m3]
    G - hmotnostní tok [kg/m2/s]
    """
    return G**2 * (1/rho_out - 1/rho_in)
